@@ -46,9 +46,9 @@ def user_info(request: Request):
 
 
 def handle_http_error(func):
-    def wrapper(request: Request):
+    def wrapper(*args, **kwargs):
         try:
-            return func(request)
+            return func(*args, **kwargs)
         except HTTPError as e:
             logging.exception(e.response.content.decode())
         except Exception as e:
